#
# spec file for package felix-gogo-runtime
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global bundle  org.apache.felix.gogo.runtime
Name:           felix-gogo-runtime
Version:        1.1.6
Release:        1.4
Summary:        Apache Felix Gogo command line shell for OSGi
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://felix.apache.org/documentation/subprojects/apache-felix-gogo.html
Source0:        http://archive.apache.org/dist/felix/%{bundle}-%{version}-source-release.tar.gz
Source1:        %{bundle}-build.xml
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  osgi-annotation
BuildRequires:  osgi-compendium
BuildRequires:  osgi-core
BuildArch:      noarch

%description
Apache Felix Gogo is a subproject of Apache Felix implementing a command
line shell for OSGi. It is used in many OSGi runtimes and servers.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n %{bundle}-%{version}
cp %{SOURCE1} build.xml

# Use compendium dep
%pom_remove_dep :org.osgi.namespace.service
%pom_remove_dep :org.osgi.service.component.annotations
%pom_remove_dep :org.osgi.service.event
%pom_xpath_inject "pom:dependencies" "
<dependency>
<groupId>org.osgi</groupId>
<artifactId>osgi.cmpn</artifactId>
</dependency>"

# These are test dependencies
%pom_change_dep junit: :::test
%pom_change_dep org.mockito: :::test

%build
mkdir -p lib
build-jar-repository -s lib osgi-annotation osgi-core osgi-compendium
%{ant} jar javadoc

%install
# jar
install -d -m 755 %{buildroot}%{_javadir}/felix
install -m 644 target/%{bundle}-%{version}.jar %{buildroot}%{_javadir}/felix/%{bundle}.jar

# pom
install -d -m 755 %{buildroot}%{_mavenpomdir}/felix
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/felix/%{bundle}.pom
%add_maven_depmap felix/%{bundle}.pom felix/%{bundle}.jar

# javadoc
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}
cp -r target/site/apidocs/* %{buildroot}/%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE NOTICE

%changelog
* Thu Feb  8 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.1.6
  * Bug
    + FELIX-6509: Evaluation of subshell String results are wrong
    on Windows
  * Improvement
    + FELIX-5970: Add requirement & capabilities model so gogo can
    be resolved
    + FELIX-5999: cleanup compiler warnings
    + FELIX-6001: cleanup compiler warnings
    + FELIX-6003: Add some resolver checks to make sure
    @RequireGogo annotation works for both jline and shell
    + FELIX-6007: create a gogo bom
    + FELIX-5963: Gogo runtime should use named executor threads
    + FELIX-6038: pull Java 7 support back in for gogo runtime,
    shell and console
* Fri Feb 10 2023 Fridrich Strba <fstrba@suse.com>
- Advertize capability needed by other felix-gogo artifacts
* Wed Mar 16 2022 Fridrich Strba <fstrba@suse.com>
- Rewrite the build system to ant so that we can eventually avoid
  build cycles with maven-plugin-bundle built against
  felix-bundlerepository
* Thu Nov 28 2019 Fridrich Strba <fstrba@suse.com>
- Specify maven.compiler.release to fix javadoc build with jdk11
* Wed May  8 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of felix-gogo-runtime 1.1.0
